@@ -2,15 +2,17 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 from datetime import datetime
-import pytz
-from typing import List
-import structlog
+from typing import List, Union
 
 import numpy as np
 import pandas as pd
+import structlog
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
 from scipy import stats
 from sklearn.base import RegressorMixin
 
+from openstf.exceptions import ModelWithoutStDev
+
 MINIMAL_RESOLUTION: int = 15  # Minimal time resolution in minutes
 
 
@@ -23,7 +25,7 @@ class ConfidenceIntervalApplicator:
     def add_confidence_interval(
         self,
         forecast: pd.DataFrame,
-        pj: dict,
+        pj: Union[dict, PredictionJobDataClass],
         default_confindence_interval: bool = False,
     ) -> pd.DataFrame:
         """Add a confidence interval to a forecast.
@@ -47,14 +49,14 @@ class ConfidenceIntervalApplicator:
 
         Args:
             forecast (pd.DataFrame): Forecast DataFram with columns: "forecast"
-            pj (dict): Prediction job
+            pj (Union[dict, PredictionJobDataClass]): Prediction job
             default_confindence_interval (bool):
                 switch to always make a default confidence interval
                 and skip quantile regression forecasting,
                 mostly used for a basecase forecast
 
         Returns:
-            pd.DataFrame: Forecast DataFram with columns: "forecast", "stdev" and
+            pd.DataFrame: Forecast DataFrame with columns: "forecast", "stdev" and
                 quantile columns
 
         """
@@ -88,8 +90,12 @@ class ConfidenceIntervalApplicator:
 
         standard_deviation = self.model.standard_deviation
 
+        # raise an exception if no valid standard deviation is available
         if standard_deviation is None:
-            return forecast
+            raise ModelWithoutStDev("No stdev available")
+
+        if standard_deviation.stdev.isnull().values.all():
+            raise ModelWithoutStDev("All stdev values are NA")
 
         # Fill stdev nans with the mean of all stdev values
         if standard_deviation.stdev.isnull().values.any():
