@@ -2,12 +2,12 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 from pathlib import Path
-from datetime import datetime, timedelta
+from typing import Union
 
 import pandas as pd
-import numpy as np
 import structlog
-from openstf.enums import ForecastType
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
+
 from openstf.feature_engineering.feature_applicator import (
     OperationalPredictFeatureApplicator,
 )
@@ -26,7 +26,7 @@ BASECASE_RESOLUTION_MINUTES = 15
 
 
 def create_basecase_forecast_pipeline(
-    pj: dict,
+    pj: Union[dict, PredictionJobDataClass],
     input_data: pd.DataFrame,
 ) -> pd.DataFrame:
     """Computes the base case forecast and confidence intervals for a given prediction job and input data.
@@ -45,7 +45,7 @@ def create_basecase_forecast_pipeline(
     # Validate and clean data - use a very long flatliner threshold.
     # If a measurement was constant for a long period, a basecase should still be made.
     validated_data = validation.validate(
-        input_data, flatliner_threshold=4 * 24 * 14 + 1
+        pj["id"], input_data, flatliner_threshold=4 * 24 * 14 + 1
     )
 
     # Add features
