@@ -1,30 +1,31 @@
 # SPDX-FileCopyrightText: 2017-2021 Alliander N.V. <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
-from typing import Union
-from datetime import datetime, timedelta, timezone
 from pathlib import Path
+from typing import Union
 
 import pandas as pd
 import structlog
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
 from sklearn.base import RegressorMixin
 
-from openstf.validation import validation
 from openstf.feature_engineering.feature_applicator import (
     OperationalPredictFeatureApplicator,
 )
 from openstf.model.confidence_interval_applicator import ConfidenceIntervalApplicator
-
+from openstf.model.fallback import generate_fallback
 from openstf.model.serializer import PersistentStorageSerializer
+from openstf.pipeline.utils import generate_forecast_datetime_range
 from openstf.postprocessing.postprocessing import (
     add_prediction_job_properties_to_forecast,
 )
-from openstf.model.fallback import generate_fallback
-from openstf.pipeline.utils import generate_forecast_datetime_range
+from openstf.validation import validation
 
 
 def create_forecast_pipeline(
-    pj: dict, input_data: pd.DataFrame, trained_models_folder: Union[str, Path]
+    pj: Union[dict, PredictionJobDataClass],
+    input_data: pd.DataFrame,
+    trained_models_folder: Union[str, Path],
 ) -> pd.DataFrame:
     """Create forecast pipeline
 
@@ -34,7 +35,7 @@ def create_forecast_pipeline(
     Expected prediction job keys: "id",
 
     Args:
-        pj (dict): Prediction job
+        pj (Union[dict, PredictionJobDataClass]): Prediction job
         input_data (pd.DataFrame): Training input data (without features)
         trained_models_folder (Path): Path where trained models are stored
 
@@ -52,7 +53,9 @@ def create_forecast_pipeline(
 
 
 def create_forecast_pipeline_core(
-    pj: dict, input_data: pd.DataFrame, model: RegressorMixin
+    pj: Union[dict, PredictionJobDataClass],
+    input_data: pd.DataFrame,
+    model: RegressorMixin,
 ) -> pd.DataFrame:
     """Create forecast pipeline (core)
 
@@ -63,7 +66,7 @@ def create_forecast_pipeline_core(
         "name", "model_type_group", "quantiles"
 
     Args:
-        pj (dict): Prediction job.
+        pj (Union[dict, PredictionJobDataClass]): Prediction job.
         input_data (pandas.DataFrame): Iput data for the prediction.
         model (RegressorMixin): Model to use for this prediction.
 
@@ -75,7 +78,7 @@ def create_forecast_pipeline_core(
     fallback_strategy = "extreme_day"  # this can later be expanded
 
     # Validate and clean data
-    validated_data = validation.validate(input_data)
+    validated_data = validation.validate(pj["id"], input_data)
 
     # Add features
     data_with_features = OperationalPredictFeatureApplicator(
