@@ -1,24 +1,24 @@
 # SPDX-FileCopyrightText: 2017-2021 Alliander N.V. <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
-from typing import List, Tuple
-
+from typing import List, Tuple, Union
 
 import pandas as pd
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
 from sklearn.base import RegressorMixin
 
 from openstf.model.confidence_interval_applicator import ConfidenceIntervalApplicator
+from openstf.pipeline.train_model import train_pipeline_common
 from openstf.postprocessing.postprocessing import (
     add_prediction_job_properties_to_forecast,
 )
-from openstf.pipeline.train_model import train_pipeline_common
 
 DEFAULT_TRAIN_HORIZONS: List[float] = [0.25, 24.0]
 DEFAULT_EARLY_STOPPING_ROUNDS: int = 10
 
 
 def train_model_and_forecast_back_test(
-    pj: dict,
+    pj: Union[dict, PredictionJobDataClass],
     input_data: pd.DataFrame,
     training_horizons: List[float] = None,
 ) -> Tuple[pd.DataFrame, RegressorMixin]:
@@ -27,7 +27,7 @@ def train_model_and_forecast_back_test(
         DO NOT USE THIS PIPELINE FOR OPERATIONAL FORECASTS
 
     Args:
-        pj (dict): Prediction job.
+        pj (Union[dict, PredictionJobDataClass]): Prediction job.
         input_data (pd.DataFrame): Input data
         training_horizons (list): horizons to train on in hours.
             These horizons are also used to make predictions (one for every horizon)
@@ -40,7 +40,7 @@ def train_model_and_forecast_back_test(
         training_horizons = DEFAULT_TRAIN_HORIZONS
 
     # Call common training pipeline
-    model, train_data, validation_data, test_data = train_pipeline_common(
+    model, report, train_data, validation_data, test_data = train_pipeline_common(
         pj, input_data, training_horizons, test_fraction=0.15, backtest=True
     )
 
