@@ -3,17 +3,23 @@
 # SPDX-License-Identifier: MPL-2.0
 import logging
 from pathlib import Path
-from typing import List, Union, Tuple
+from typing import List, Tuple, Union
 
 import pandas as pd
-from sklearn.base import RegressorMixin
 import structlog
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
 
+from openstf.exceptions import (
+    InputDataInsufficientError,
+    InputDataWrongColumnOrderError,
+    OldModelHigherScoreError,
+)
 from openstf.feature_engineering.feature_applicator import TrainFeatureApplicator
-from openstf.model.standard_deviation_generator import StandardDeviationGenerator
+from openstf.metrics.reporter import Report, Reporter
 from openstf.model.model_creator import ModelCreator
-from openstf.metrics.reporter import Reporter, Report
+from openstf.model.regressors.regressor import OpenstfRegressor
 from openstf.model.serializer import PersistentStorageSerializer
+from openstf.model.standard_deviation_generator import StandardDeviationGenerator
 from openstf.model_selection.model_selection import split_data_train_validation_test
 from openstf.validation import validation
 
@@ -25,23 +31,21 @@ PENALTY_FACTOR_OLD_MODEL: float = 1.2
 
 
 def train_model_pipeline(
-    pj: dict,
+    pj: Union[dict, PredictionJobDataClass],
     input_data: pd.DataFrame,
     check_old_model_age: bool,
     trained_models_folder: Union[str, Path],
-    save_figures_folder: Union[str, Path],
 ) -> None:
     """Midle level pipeline that takes care of all persistent storage dependencies
 
-    Expected prediction jobs keys: "id", "name", "model", "hyper_params",
+    Expected prediction jobs keys: "id", "model", "hyper_params",
         "feature_names"
 
     Args:
-        pj (dict): Prediction job
+        pj (Union[dict, PredictionJobDataClass]): Prediction job
         input_data (pd.DataFrame): Raw training input data
         check_old_model_age (bool): Check if training should be skipped because the model is too young
         trained_models_folder (Path): Path where trained models are stored
-        save_figures_folder (Path): path were reports (mostly figures) about the training procces are stored
 
     Returns:
         None
@@ -60,7 +64,7 @@ def train_model_pipeline(
     except FileNotFoundError:
         old_model = None
         old_model_age = float("inf")
-        logger.warning("No old model found, training new model")
+        logger.warning("No old model found, training new model", pid=pj["id"])
 
     # Check old model age and continue yes/no
     if (old_model_age < MAXIMUM_MODEL_AGE) and check_old_model_age:
@@ -72,23 +76,36 @@ def train_model_pipeline(
     # Train model with core pipeline
     try:
         model, report = train_model_pipeline_core(pj, input_data, old_model)
-    except RuntimeError as e:
-        logger.error(f"Old model is better than new model for {pj['name']}", exc_info=e)
+    except OldModelHigherScoreError as OMHSE:
+        logger.error("Old model is better than new model", pid=pj["id"], exc_info=OMHSE)
         return
 
-    # Save model
-    serializer.save_model(model, pid=pj["id"])
+    except InputDataInsufficientError as IDIE:
+        logger.error(
+            "Input data is insufficient after validation and cleaning",
+            pid=pj["id"],
+            exc_info=IDIE,
+        )
+        raise InputDataInsufficientError(IDIE)
 
-    # Save reports/figures
-    report.save_figures(save_path=save_figures_folder)
+    except InputDataWrongColumnOrderError as IDWCOE:
+        logger.error(
+            "Wrong column order, 'load' column should be first and 'horizon' column last.",
+            pid=pj["id"],
+            exc_info=IDWCOE,
+        )
+        raise InputDataWrongColumnOrderError(IDWCOE)
+
+    # Save model
+    serializer.save_model(model, pj=pj, report=report)
 
 
 def train_model_pipeline_core(
-    pj: dict,
+    pj: Union[dict, PredictionJobDataClass],
     input_data: pd.DataFrame,
-    old_model: RegressorMixin = None,
+    old_model: OpenstfRegressor = None,
     horizons: List[float] = None,
-) -> Tuple[RegressorMixin, Report]:
+) -> Tuple[OpenstfRegressor, Report]:
     """Train model core pipeline.
     Trains a new model given a predction job, input data and compares it to an old model.
     This pipeline has no database or persisitent storage dependencies.
@@ -98,20 +115,21 @@ def train_model_pipeline_core(
 
     For training a model the following keys in the prediction job dictionairy are
     expected:
-        "name"          Arbitray name only used for logging
+        "id"            Only used for logging
         "model"         Model type, any of "xgb", "lgb",
         "hyper_params"  Hyper parameters dictionairy specific to the model_type
         "feature_names"      List of features to train model on or None to use all features
 
     Args:
-        pj (dict): Prediction job
+        pj (Union[dict, PredictionJobDataClass]): Prediction job
         input_data (pd.DataFrame): Input data
         old_model (RegressorMixin, optional): Old model to compare to. Defaults to None.
         horizons (List[float]): horizons to train on in hours.
 
     Raises:
-        ValueError: When input data is insufficient
-        RuntimeError: When old model is better than new model
+        InputDataInsufficientError: when input data is insufficient.
+        InputDataWrongColumnOrderError: when input data has a invalid column order.
+        OldModelHigherScoreError: When old model is better than new model.
 
     Returns:
         Tuple[RegressorMixin, Report]: Trained model and report (with figures)
@@ -123,7 +141,7 @@ def train_model_pipeline_core(
     logger = structlog.get_logger(__name__)
 
     # Call common pipeline
-    model, train_data, validation_data, test_data = train_pipeline_common(
+    model, report, train_data, validation_data, test_data = train_pipeline_common(
         pj, input_data, horizons
     )
 
@@ -131,8 +149,11 @@ def train_model_pipeline_core(
 
     # Check if new model is better than old model
     if old_model:
-        combined = train_data.append(validation_data)
-        x_data, y_data = combined.iloc[:, 1:-1], combined.iloc[:, 0]
+        combined = train_data.append(validation_data).reset_index(drop=True)
+        x_data, y_data = (
+            combined.iloc[:, 1:-1],
+            combined.iloc[:, 0],
+        )
 
         # Score method always returns R^2
         score_new_model = model.score(x_data, y_data)
@@ -145,78 +166,85 @@ def train_model_pipeline_core(
 
             # Check if R^2 is better for old model
             if score_old_model > score_new_model * PENALTY_FACTOR_OLD_MODEL:
-                raise (
-                    RuntimeError(
-                        f"Old model is better than new model for {pj['name']}."
-                        f"NOT updating model"
-                    )
+                raise OldModelHigherScoreError(
+                    f"Old model is better than new model for {pj['id']}."
                 )
 
             logger.info(
                 "New model is better than old model, continuing with training procces"
             )
         except ValueError as e:
-            logging.info("Could not compare to old model", exc_info=e)
-
-    # Report about the training procces
-    report = Reporter(pj, train_data, validation_data, test_data).generate_report(model)
+            logger.info("Could not compare to old model", pid=pj["id"], exc_info=e)
 
     return model, report
 
 
 def train_pipeline_common(
-    pj: dict,
+    pj: Union[dict, PredictionJobDataClass],
     input_data: pd.DataFrame,
     horizons: List[float],
     test_fraction: float = 0.0,
     backtest: bool = False,
-) -> Tuple[RegressorMixin, pd.DataFrame, pd.DataFrame, pd.DataFrame]:
+) -> Tuple[OpenstfRegressor, pd.DataFrame, pd.DataFrame, pd.DataFrame]:
     """Common pipeline shared with operational training and backtest training
 
     Args:
-        pj (dict): Prediction job
+        pj (Union[dict, PredictionJobDataClass]): Prediction job
         input_data (pd.DataFrame): Input data
         horizons (List[float]): horizons to train on in hours.
 
     Returns:
-        Tuple[RegressorMixin, pd.DataFrame, pd.DataFrame, pd.DataFrame]: Trained model,
+        Tuple[RegressorMixin, Report, pd.DataFrame, pd.DataFrame, pd.DataFrame]: Trained model, report
          train_data, validation_data and test_data
 
+    Raises:
+        InputDataInsufficientError: when input data is insufficient.
+        InputDataWrongColumnOrderError: when input data has a invalid column order.
 
     """
+    if input_data.empty:
+        raise InputDataInsufficientError("Input dataframe is empty")
+    elif "load" not in input_data.columns:
+        raise InputDataWrongColumnOrderError(
+            "Missing the load column in the input dataframe"
+        )
 
-    # Validate and clean data
-    validated_data = validation.clean(validation.validate(input_data))
+        # Validate and clean data
+    validated_data = validation.clean(validation.validate(pj["id"], input_data))
 
     # Check if sufficient data is left after cleaning
     if not validation.is_data_sufficient(validated_data):
-        raise ValueError(
-            f"Input data is insufficient for {pj['name']} "
-            f"after validation and cleaning"
+        raise InputDataInsufficientError(
+            "Input data is insufficient, after validation and cleaning"
         )
 
-    # Add features
     data_with_features = TrainFeatureApplicator(
         horizons=horizons, feature_names=pj["feature_names"]
     ).add_features(validated_data)
 
     # Split data
-    train_data, validation_data, test_data = split_data_train_validation_test(
+    (
+        peaks,
+        peaks_val_train,
+        train_data,
+        validation_data,
+        test_data,
+    ) = split_data_train_validation_test(
         data_with_features,
         test_fraction=test_fraction,
-        backtest=backtest,
+        back_test=backtest,
     )
 
-    # Create relevant model
-    model = ModelCreator.create_model(pj["model"], quantiles=pj["quantiles"])
-
     # Test if first column is "load" and last column is "horizon"
     if train_data.columns[0] != "load" or train_data.columns[-1] != "horizon":
-        raise RuntimeError(
-            "Column order in train input data not as expected, "
-            "could not train a model!"
+        raise InputDataWrongColumnOrderError(
+            f"Wrong column order for {pj['id']} "
+            "'load' column should be first and 'horizon' column last."
         )
 
+    # Create relevant model
+    model = ModelCreator.create_model(pj["model"], quantiles=pj["quantiles"])
+
     # split x and y data
     train_x, train_y = train_data.iloc[:, 1:-1], train_data.iloc[:, 0]
     validation_x, validation_y = (
@@ -227,7 +255,14 @@ def train_pipeline_common(
     # Configure evals for early stopping
     eval_set = [(train_x, train_y), (validation_x, validation_y)]
 
-    model.set_params(**pj["hyper_params"])
+    # Set relevant hyperparameters
+    valid_hyper_parameters = {
+        key: value
+        for key, value in pj["hyper_params"].items()
+        if key in model.get_params().keys()
+    }
+
+    model.set_params(**valid_hyper_parameters)
     model.fit(
         train_x,
         train_y,
@@ -235,13 +270,21 @@ def train_pipeline_common(
         early_stopping_rounds=DEFAULT_EARLY_STOPPING_ROUNDS,
         verbose=False,
     )
+    # Gets the feature importance df or None if we don't have feature importance
+    model.feature_importance_dataframe = model.set_feature_importance(train_x.columns)
+
     logging.info("Fitted a new model, not yet stored")
 
     # Do confidence interval determination
     model = StandardDeviationGenerator(
         validation_data
     ).generate_standard_deviation_data(model)
-    return model, train_data, validation_data, test_data
+
+    # Report about the training process
+    reporter = Reporter(train_data, validation_data, test_data)
+    report = reporter.generate_report(model)
+
+    return model, report, train_data, validation_data, test_data
 
 
 def get_model_age(trained_models_folder: str, pid: int) -> float:
