@@ -2,13 +2,16 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 
+from enum import Enum
+from typing import Union
+
 import numpy as np
 import pandas as pd
 import structlog
-from enum import Enum
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
 
-from openstf.feature_engineering import weather_features
 from openstf.enums import ForecastType
+from openstf.feature_engineering import weather_features
 
 
 def normalize_and_convert_weather_data_for_splitting(weather_data):
@@ -128,7 +131,7 @@ def post_process_wind_solar(forecast: pd.Series, forecast_type):
     Args:
         forecast (pd.Series): Series with forecast data.
         forecast_type (ForecastType): Specifies the type of forecast. This can be retrieved
-            from the prediction job as pj['typ']
+            from the prediction job as pj['forecast_type']
 
     Returns:
         forecast (pd.DataFrame): post-processed forecast.
@@ -176,7 +179,7 @@ def add_components_base_case_forecast(basecase_forecast: pd.DataFrame) -> pd.Dat
 
 
 def add_prediction_job_properties_to_forecast(
-    pj: dict,
+    pj: Union[dict, PredictionJobDataClass],
     forecast: pd.DataFrame,
     algorithm_type: str,
     forecast_type: Enum = None,
@@ -187,7 +190,7 @@ def add_prediction_job_properties_to_forecast(
 
     logger.info("Postproces in preparation of storing")
     if forecast_type is None:
-        forecast_type = pj["typ"]
+        forecast_type = pj["forecast_type"]
     else:
         # get the value from the enum
         forecast_type = forecast_type.value
