@@ -19,8 +19,11 @@ Example:
         $ python create_basecase_forecast.py
 """
 from datetime import datetime, timedelta
-import pandas as pd
 from pathlib import Path
+from typing import Union
+
+import pandas as pd
+from openstf_dbc.services.prediction_job import PredictionJobDataClass
 
 from openstf.pipeline.create_basecase_forecast import create_basecase_forecast_pipeline
 from openstf.tasks.utils.predictionjobloop import PredictionJobLoop
@@ -30,12 +33,14 @@ T_BEHIND_DAYS: int = 15
 T_AHEAD_DAYS: int = 14
 
 
-def create_basecase_forecast_task(pj: dict, context: TaskContext) -> None:
+def create_basecase_forecast_task(
+    pj: Union[dict, PredictionJobDataClass], context: TaskContext
+) -> None:
     """Top level task that creates a basecase forecast.
     On this task level all database and context manager dependencies are resolved.
 
     Args:
-        pj (dict): Prediction job
+        pj (Union[dict, PredictionJobDataClass]): Prediction job
         context (TaskContext): Contect object that holds a config manager and a database connection
     """
     # Define datetime range for input data
@@ -69,7 +74,7 @@ def main():
     taskname = Path(__file__).name.replace(".py", "")
 
     with TaskContext(taskname) as context:
-        model_type = ["xgb", "lgb"]
+        model_type = ["xgb", "xgb_quantile", "lgb"]
 
         PredictionJobLoop(context, model_type=model_type).map(
             create_basecase_forecast_task, context
