@@ -40,11 +40,11 @@ Attributes:
 
 from pathlib import Path
 
-from openstf.monitoring import teams
-from openstf.tasks.utils.taskcontext import TaskContext
-from openstf.tasks.train_model import train_model_task
-from openstf.tasks.optimize_hyperparameters import optimize_hyperparameters_task
 from openstf.enums import TracyJobResult
+from openstf.monitoring import teams
+from openstf.tasks.optimize_hyperparameters import optimize_hyperparameters_task
+from openstf.tasks.train_model import train_model_task
+from openstf.tasks.utils.taskcontext import TaskContext
 
 
 def run_tracy(context):
@@ -53,7 +53,7 @@ def run_tracy(context):
     num_jobs = len(tracy_jobs)
 
     if num_jobs == 0:
-        context.logger.warning("Number of tracy jobs is {num_jobs}, exit task")
+        context.logger.warning(f"Number of tracy jobs is {num_jobs}, exit task")
         return
 
     context.logger.info("Start processing Tracy jobs", num_jobs=num_jobs)
