@@ -27,24 +27,27 @@ Attributes:
 
 """
 from datetime import datetime
+from pathlib import Path
 
 import numpy as np
 import pandas as pd
-from ktpbase.database import DataBase
-import structlog
 import scipy.optimize
+import structlog
+from openstf_dbc.database import DataBase
 
+import openstf.monitoring.teams as monitoring
+from openstf.enums import MLModelType
 from openstf.tasks.utils.predictionjobloop import PredictionJobLoop
 from openstf.tasks.utils.taskcontext import TaskContext
-import openstf.monitoring.teams as monitoring
-
 
 COEF_MAX_FRACTION_DIFF = 0.3
 
 
 def main():
-    with TaskContext("split_forecast") as context:
-        model_type = ["xgb", "lgb"]
+    taskname = Path(__file__).name.replace(".py", "")
+
+    with TaskContext(taskname) as context:
+        model_type = [ml.value for ml in MLModelType]
 
         PredictionJobLoop(
             context,
@@ -146,7 +149,7 @@ def convert_coefdict_to_coefsdf(pj, input_split_function, coefdict):
     storage.
 
     Args:
-        pj (PredictionJob): prediction job
+        pj (Union[dict, PredictionJobDataClass]): prediction job
         input_split_function (pd.DataFrame): df of columns of standard load profiles,
             i.e. wind, solar, household
         coefdict (dict): dict of coefficient per standard load profile
