@@ -4,6 +4,7 @@
 
 import random
 import sys
+from collections import defaultdict
 
 
 class PredictionJobLoop:
@@ -25,6 +26,8 @@ class PredictionJobLoop:
         function. If another set of prediction jobs is desired, manually pass
         them using the prediction_jobs argument.
 
+        Tip: For debugging a specific PID, use prediction_jobs=[dict(id={specific_pid})]
+
         Args:
             context (openstf.tasks.util.taskcontext.TaskContext): The
                 context to run this loop in.
@@ -61,9 +64,7 @@ class PredictionJobLoop:
         if prediction_jobs is None:
             self.prediction_jobs = self._get_prediction_jobs()
         else:
-            self.prediction_jobs = self._add_missing_info_prediction_jobs(
-                prediction_jobs
-            )
+            self.prediction_jobs = prediction_jobs
 
         if self.random_order:
             random.shuffle(self.prediction_jobs)
@@ -77,18 +78,6 @@ class PredictionJobLoop:
 
         return prediction_jobs
 
-    def _add_missing_info_prediction_jobs(self, prediction_jobs_input):
-        prediction_jobs = []
-
-        for pj in prediction_jobs_input:
-            if len(pj.keys()) > 1:
-                prediction_jobs.append(pj)
-                continue
-
-            prediction_jobs.append(self.context.database.get_prediction_job(pj["id"]))
-
-        return prediction_jobs
-
     def map(self, function, *args, **kwargs):
         """Maps the passed function over all prediction jobs.
 
@@ -106,6 +95,7 @@ class PredictionJobLoop:
         """
         pids_successful = []
         pids_unsuccessful = []
+        pids_unsuccessful_dict = defaultdict(list)
         last_job_exception = None
 
         num_jobs = len(self.prediction_jobs)
@@ -116,16 +106,12 @@ class PredictionJobLoop:
             successful = False
 
             self.context.logger = self.context.logger.bind(
-                prediction_id=prediction_job.get("id"),
-                prediction_name=prediction_job.get("name", ""),
+                prediction_id=prediction_job["id"],
+                prediction_name=prediction_job["name"],
             )
 
             self.context.perf_meter.start_level(
-                "iteration",
-                i,
-                num_jobs=num_jobs,
-                pid=prediction_job.get("id"),
-                **kwargs
+                "iteration", i, num_jobs=num_jobs, pid=prediction_job["id"], **kwargs
             )
 
             try:
@@ -138,6 +124,7 @@ class PredictionJobLoop:
 
             except Exception as exception:
                 pids_unsuccessful.append(prediction_job["id"])
+                pids_unsuccessful_dict[str(exception)].append(prediction_job["id"])
                 last_job_exception = exception
 
                 self._handle_exception_during_iteration(prediction_job, exception)
@@ -168,6 +155,7 @@ class PredictionJobLoop:
                 "num_jobs": num_jobs,
                 "pids_successful": pids_successful,
                 "pids_unsuccessful": pids_unsuccessful,
+                "exceptions": pids_unsuccessful_dict,
                 "jobs_successful": jobs_successful,
                 "jobs_unsuccessful": jobs_unsuccessful,
                 "jobs_started": jobs_started,
