@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from datetime import timedelta
+from typing import Union
 
 import numpy as np
 import pandas as pd
@@ -22,31 +23,47 @@ FLATLINER_TRESHOLD = 24
 
 
 def validate(
-    data: pd.DataFrame, flatliner_threshold: int = FLATLINER_TRESHOLD
+    pj_id: Union[int, str],
+    data: pd.DataFrame,
+    flatliner_threshold: int = FLATLINER_TRESHOLD,
 ) -> pd.DataFrame:
     logger = structlog.get_logger(__name__)
     # Drop 'false' measurements. e.g. where load appears to be constant.
     data = replace_repeated_values_with_nan(
         data, max_length=flatliner_threshold, column_name=data.columns[0]
     )
-    num_const_load_values = len(data) - len(data.iloc[:, 0].dropna())
-    logger.debug(
-        f"Changed {num_const_load_values} values of constant load to NA.",
-        num_const_load_values=num_const_load_values,
+    num_repeated_values = len(data) - len(data.iloc[:, 0].dropna())
+    if num_repeated_values > 0:
+        frac_const_load_values = num_repeated_values / len(data.index)
+    else:
+        frac_const_load_values = 0.0
+    logger.warning(
+        f"Found {num_repeated_values} values of constant load (repeated values), converted to NaN value.",
+        cleansing_step="repeated_values",
+        pj_id=pj_id,
+        num_values=num_repeated_values,
+        frac_values=frac_const_load_values,
     )
 
     # Check for repeated load observations due to invalid measurements
-    suspicious_moments = find_nonzero_flatliner(data, threshold=flatliner_threshold)
-    if suspicious_moments is not None:
+    nonzero_flatliners = find_nonzero_flatliner(data, threshold=flatliner_threshold)
+    if nonzero_flatliners is not None:
         # Covert repeated load observations to NaN values
-        data = replace_invalid_data(data, suspicious_moments)
+        data = replace_invalid_data(data, nonzero_flatliners)
         # Calculate number of NaN values
         # TODO should this not be part of the replace_invalid_data function?
-        num_nan = sum([True for i, row in data.iterrows() if all(row.isnull())])
-        logger.warning(
-            "Found suspicious data points, converted to NaN value",
-            num_nan_values=num_nan,
-        )
+        num_nan_values = sum([True for i, row in data.iterrows() if all(row.isnull())])
+        frac_nan_values = num_nan_values / len(data.index)
+    else:
+        num_nan_values = 0
+        frac_nan_values = 0.0
+    logger.warning(
+        f"Found {num_nan_values} nonzero flatliner data points, converted to NaN value.",
+        cleansing_step="nonzero_flatliner_data_points",
+        pj_id=pj_id,
+        num_values=num_nan_values,
+        frac_values=frac_nan_values,
+    )
     return data
 
 
@@ -59,7 +76,8 @@ def clean(data: pd.DataFrame) -> pd.DataFrame:
     data = data.loc[np.isnan(data.iloc[:, 0]) != True, :]  # noqa E712
     num_removed_values = len_original - len(data)
     logger.debug(
-        f"Removed {num_removed_values} NA values", num_removed_values=num_removed_values
+        f"Removed {num_removed_values} NaN values",
+        num_removed_values=num_removed_values,
     )
     return data
 
